@@ -32,7 +32,6 @@
 #include <assert.h>
 #include <stdio.h>
 #include <string.h>
-#include <limits.h>
 #include <stdio.h>
 
 
@@ -236,10 +235,10 @@ bool _glfwRefreshContextAttribs(_GLFWwindow* window,
         }
     }
 
-    if (!sscanf(version, "%d.%d.%d",
+    if (sscanf(version, "%d.%d.%d",
                 &window->context.major,
                 &window->context.minor,
-                &window->context.revision))
+                &window->context.revision) < 1)
     {
         if (window->context.client == GLFW_OPENGL_API)
         {
@@ -435,11 +434,11 @@ bool _glfwStringInExtensionString(const char* string, const char* extensions)
 
 GLFWAPI void glfwMakeContextCurrent(GLFWwindow* handle)
 {
+    _GLFW_REQUIRE_INIT();
+
     _GLFWwindow* window = (_GLFWwindow*) handle;
     _GLFWwindow* previous = _glfwPlatformGetTls(&_glfw.contextSlot);
 
-    _GLFW_REQUIRE_INIT();
-
     if (window && window->context.client == GLFW_NO_API)
     {
         _glfwInputError(GLFW_NO_WINDOW_CONTEXT,
@@ -477,6 +476,9 @@ GLFWAPI void glfwSwapBuffers(GLFWwindow* handle)
         return;
     }
 
+#ifdef _GLFW_WAYLAND
+    _glfwWaylandBeforeBufferSwap(window);
+#endif
     window->context.swapBuffers(window);
 #ifdef _GLFW_WAYLAND
     _glfwWaylandAfterBufferSwap(window);
