@@ -185,6 +185,9 @@ typedef struct _GLFWwindowWayland
         struct zwlr_layer_surface_v1* zwlr_layer_surface_v1;
     } layer_shell;
 
+    struct {
+        int width, height, dirty;
+    } framebuffer_size_at_last_resize;
     /* information about axis events on current frame */
     struct
     {
@@ -233,7 +236,7 @@ typedef struct _GLFWwindowWayland
         struct {
             int width, height;
             bool focused, needs_shadow;
-            float fscale;
+            double fscale;
             WaylandWindowState toplevel_states;
         } for_window_state;
 
@@ -420,10 +423,11 @@ typedef struct _GLFWcursorWayland
 
 
 void _glfwAddOutputWayland(uint32_t name, uint32_t version);
+void _glfwWaylandBeforeBufferSwap(_GLFWwindow *window);
 void _glfwWaylandAfterBufferSwap(_GLFWwindow *window);
 void _glfwSetupWaylandDataDevice(void);
 void _glfwSetupWaylandPrimarySelectionDevice(void);
-float _glfwWaylandWindowScale(_GLFWwindow*);
+double _glfwWaylandWindowScale(_GLFWwindow*);
 int _glfwWaylandIntegerWindowScale(_GLFWwindow*);
 void animateCursorImage(id_type timer_id, void *data);
 struct wl_cursor* _glfwLoadCursor(GLFWCursorShape, struct wl_cursor_theme*);
