@@ -594,6 +594,31 @@ draw_tint(bool premult, Screen *screen, const CellRenderData *crd) {
     glDrawArrays(GL_TRIANGLE_FAN, 0, 4);
 }
 
+static bool
+draw_scroll_indicator(bool premult, Screen *screen, const CellRenderData *crd) {
+    if (OPT(scrollback_indicator_opacity) <= 0 || screen->linebuf != screen->main_linebuf || !screen->scrolled_by) return false;
+    glEnable(GL_BLEND);
+    if (premult) { BLEND_PREMULT } else { BLEND_ONTO_OPAQUE }
+    bind_program(TINT_PROGRAM);
+    const color_type bar_color = colorprofile_to_color(screen->color_profile, screen->color_profile->overridden.highlight_bg, screen->color_profile->configured.highlight_bg).rgb;
+    GLfloat alpha = 0.8f;
+    float frac = (float)screen->scrolled_by / (float)screen->historybuf->count;
+    const GLfloat bar_height = crd->gl.dy;
+    GLfloat bottom = (crd->gl.ystart - crd->gl.height);
+    bottom += MAX(0, crd->gl.height - bar_height) * frac;
+#define C(shift) srgb_color((bar_color >> shift) & 0xFF) * premult_factor
+    GLfloat premult_factor = premult ? alpha : 1.0f;
+    glUniform4f(tint_program_layout.uniforms.tint_color, C(16), C(8), C(0), alpha);
+#undef C
+    GLfloat width = 0.5f * crd->gl.dx;
+    GLfloat left = (GLfloat)(crd->gl.xstart + (screen->columns * crd->gl.dx - width));
+    glUniform4f(tint_program_layout.uniforms.edges, left, bottom, left + width, bottom + bar_height);
+    glDrawArrays(GL_TRIANGLE_FAN, 0, 4);
+    glDisable(GL_BLEND);
+    return true;
+}
+
+
 static float prev_inactive_text_alpha = -1;
 
 static void
@@ -935,7 +960,7 @@ get_visual_bell_intensity(Screen *screen) {
 }
 
 void
-draw_cells(ssize_t vao_idx, const WindowRenderData *srd, OSWindow *os_window, bool is_active_window, bool can_be_focused, Window *window) {
+draw_cells(ssize_t vao_idx, const WindowRenderData *srd, OSWindow *os_window, bool is_active_window, bool is_tab_bar, bool is_single_window, Window *window) {
     float x_ratio = 1., y_ratio = 1.;
     if (os_window->live_resize.in_progress) {
         x_ratio = (float) os_window->viewport_width / (float) os_window->live_resize.width;
@@ -953,7 +978,11 @@ draw_cells(ssize_t vao_idx, const WindowRenderData *srd, OSWindow *os_window, bo
     bind_vao_uniform_buffer(vao_idx, uniform_buffer, cell_program_layouts[CELL_PROGRAM].render_data.index);
     bind_vertex_array(vao_idx);
 
-    float current_inactive_text_alpha = (!can_be_focused || screen->cursor_render_info.is_focused) && is_active_window ? 1.0f : (float)OPT(inactive_text_alpha);
+    // We draw with inactive text alpha if:
+    // - We're not drawing the tab bar
+    // - There's only a single window and the os window is not focused
+    // - There are multiple windows and the current window is not active
+    float current_inactive_text_alpha = is_tab_bar || (!is_single_window && is_active_window) || (is_single_window && screen->cursor_render_info.is_focused) ? 1.0f : (float)OPT(inactive_text_alpha);
     set_cell_uniforms(current_inactive_text_alpha, screen->reload_all_gpu_data);
     screen->reload_all_gpu_data = false;
     bool has_underlying_image = has_bgimage(os_window);
@@ -972,14 +1001,16 @@ draw_cells(ssize_t vao_idx, const WindowRenderData *srd, OSWindow *os_window, bo
                 scale_rendered_graphic(grman->render_data.item + i, srd->xstart, srd->ystart, crd.x_ratio, crd.y_ratio);
         }
     }
+    bool use_premult = false;
     has_underlying_image |= grman->num_of_below_refs > 0 || grman->num_of_negative_refs > 0;
     if (os_window->is_semi_transparent) {
-        if (has_underlying_image) draw_cells_interleaved_premult(vao_idx, screen, os_window, &crd, wl);
+        if (has_underlying_image) { draw_cells_interleaved_premult(vao_idx, screen, os_window, &crd, wl); use_premult = true; }
         else draw_cells_simple(vao_idx, screen, &crd, os_window->is_semi_transparent);
     } else {
         if (has_underlying_image) draw_cells_interleaved(vao_idx, screen, os_window, &crd, wl);
         else draw_cells_simple(vao_idx, screen, &crd, os_window->is_semi_transparent);
     }
+    draw_scroll_indicator(use_premult, screen, &crd);
 
     if (screen->start_visual_bell_at) {
         GLfloat intensity = get_visual_bell_intensity(screen);
